stable_function
===============

A well-tested, production-ready function.

.. py:function:: stable_function(x, y)

   Compute the sum of *x* and *y*.

   .. badges:: stability:stable area:math

   :param x: First operand.
   :param y: Second operand.
   :returns: ``x + y``
